@@ -1,12 +1,12 @@
 use strict;
 
-# $Id: RDF.pm,v 1.53 2006/03/14 03:34:43 asc Exp $
+# $Id: RDF.pm,v 1.55 2006/05/31 01:02:06 asc Exp $
 # -*-perl-*-
 
 package Net::Flickr::RDF;
 use base qw (Net::Flickr::API);
 
-$Net::Flickr::RDF::VERSION = '1.6';
+$Net::Flickr::RDF::VERSION = '1.7';
 
 =head1 NAME
 
@@ -909,6 +909,7 @@ sub make_photo_triples {
                 push @triples, [$uri, $self->uri_shortform("exifi", "height"), $data->{files}->{$label}->{height}];
                 push @triples, [$uri, $self->uri_shortform("dcterms", "relation"), $label];
                 push @triples, [$uri, $self->uri_shortform("rdfs", "seeAlso"), $photo];
+                push @triples, [$uri, $self->uri_shortform("rdfs", "seeAlso"), "$photo#exif"];
                 push @triples, [$uri, $self->uri_shortform("rdf", "type"), $self->uri_shortform("dcterms","StillImage")];
                 
                 if ($label ne "Original") {
@@ -1023,12 +1024,17 @@ sub make_photo_triples {
         # EXIF data
         #
         
+        # dateTimeOriginal : EXIF/36867
+        # dateTimeDigitzed : EXIF/36868
+
         foreach my $facet (keys %{$data->{exif}}) {
                 
                 if (! exists($RDFMAP{$facet})) {
                         next;
                 }
                 
+                my $photo_o_url = $data->{files}->{Original}->{uri};
+
                 foreach my $tag (keys %{$data->{exif}->{$facet}}) {
                         
                         my $label = $RDFMAP{$facet}->{$tag};
@@ -1037,10 +1043,18 @@ sub make_photo_triples {
                                 $self->log()->warning("can't find any label for $facet tag : $tag");
                                 next;
                         }
-                        
+
                         my $value = $data->{exif}->{$facet}->{$tag};
+
+                        # dateTimeOriginal/Digitized
+
+                        if (($facet eq "EXIF") && (($tag == 36867) || ($tag == 36868))) {
+
+                                my $time = str2time($value);
+                                $value   = time2str("%Y-%m-%dT%H:%M:%S%Z", $time);
+                        }
                         
-                        push @triples, [$photo, $self->uri_shortform("exif","$label"), "$value"];
+                        push @triples, ["$photo#exif", $self->uri_shortform("exif","$label"), "$value"];
                 }
         }
         
@@ -1514,11 +1528,11 @@ sub serialize_triples {
 
 =head1 VERSION
 
-1.6
+1.7
 
 =head1 DATE
 
-$Date: 2006/03/14 03:34:43 $
+$Date: 2006/05/31 01:02:06 $
 
 =head1 AUTHOR
 
@@ -1541,45 +1555,32 @@ from Flickr
 This is an example of an RDF dump for a photograph backed up from Flickr :
 
  <?xml version='1.0'?>    
- <rdf:RDF
-  xmlns:dc="http://purl.org/dc/elements/1.1/"
-  xmlns:geo="http://www.w3.org/2003/01/geo/wgs84_pos#"
-  xmlns:a="http://www.w3.org/2000/10/annotation-ns"
-  xmlns:acl="http://www.w3.org/2001/02/acls#"
-  xmlns:exif="http://nwalsh.com/rdf/exif#"
-  xmlns:skos="http://www.w3.org/2004/02/skos/core#"
-  xmlns:cc="http://web.resource.org/cc/"
-  xmlns:foaf="http://xmlns.com/foaf/0.1/"
-  xmlns:exifi="http://nwalsh.com/rdf/exif-intrinsic#"
-  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
-  xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
-  xmlns:flickr="x-urn:flickr:"
-  xmlns:dcterms="http://purl.org/dc/terms/"
-  xmlns:i="http://www.w3.org/2004/02/image-regions#">
+  <rdf:RDF
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:geo="http://www.w3.org/2003/01/geo/wgs84_pos#"
+   xmlns:a="http://www.w3.org/2000/10/annotation-ns"
+   xmlns:acl="http://www.w3.org/2001/02/acls#"
+   xmlns:exif="http://nwalsh.com/rdf/exif#"
+   xmlns:skos="http://www.w3.org/2004/02/skos/core#"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:foaf="http://xmlns.com/foaf/0.1/"
+   xmlns:exifi="http://nwalsh.com/rdf/exif-intrinsic#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
+   xmlns:flickr="x-urn:flickr:"
+   xmlns:dcterms="http://purl.org/dc/terms/"
+   xmlns:i="http://www.w3.org/2004/02/image-regions#"
+   >
 
-  <flickr:photo rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528">
-    <exif:isoSpeedRatings>1250</exif:isoSpeedRatings>
-    <exif:apertureValue>336/100</exif:apertureValue>
-    <exif:pixelYDimension>960</exif:pixelYDimension>
-    <exif:focalLength>4.5 mm</exif:focalLength>
-    <acl:access>visbility</acl:access>
-    <exif:colorSpace>sRGB</exif:colorSpace>
-    <exif:dateTimeOriginal>2005:08:02 18:12:19</exif:dateTimeOriginal>
-    <exif:shutterSpeedValue>4321/1000</exif:shutterSpeedValue>
+   <flickr:photo rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528">
     <dc:description></dc:description>
-    <exif:exposureTime>0.05 sec (263/5260)</exif:exposureTime>
-    <dc:created>2005-08-02T18:12:19-0700</dc:created>
-    <dc:dateSubmitted>2005-08-02T18:16:20-0700</dc:dateSubmitted>
-    <exif:gainControl>High gain up</exif:gainControl>
-    <exif:flash>32</exif:flash>
-    <exif:digitalZoomRatio>100/100</exif:digitalZoomRatio>
-    <exif:pixelXDimension>1280</exif:pixelXDimension>
-    <exif:dateTimeDigitized>2005:08:02 18:12:19</exif:dateTimeDigitized>
-    <dc:title>20050802(007).jpg</dc:title>
-    <exif:fNumber>f/3.2</exif:fNumber>
-    <acl:accessor>public</acl:accessor>
     <geo:long>-122.417068</geo:long>
+    <acl:access>visbility</acl:access>
     <geo:lat>37.7742</geo:lat>
+    <dc:created>2005-08-02T18:12:19-0700</dc:created>
+    <dc:title>20050802(007).jpg</dc:title>
+    <acl:accessor>public</acl:accessor>
+    <dc:dateSubmitted>2005-08-02T18:16:20-0700</dc:dateSubmitted>
     <cc:license rdf:resource="http://creativecommons.org/licenses/by-nd/2.0/"/>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <dc:subject rdf:resource="http://www.flickr.com/photos/35034348999@N01/tags/sanfrancisco"/>
@@ -1602,279 +1603,301 @@ This is an example of an RDF dump for a photograph backed up from Flickr :
     <a:hasAnnotation rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528#note-1148950"/>
     <a:hasAnnotation rdf:resource="http://www.flickr.com/photos/straup/30763528/#comment8400103"/>
     <a:hasAnnotation rdf:resource="http://www.flickr.com/photos/straup/30763528/#comment8399772"/>
-  </flickr:photo>
+   </flickr:photo>
 
-  <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_s.jpg">
+   <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_s.jpg">
     <dcterms:relation>Square</dcterms:relation>
     <exifi:height>75</exifi:height>
     <exifi:width>75</exifi:width>
     <dcterms:isVersionOf rdf:resource="http://static.flickr.com/23/30763528_a981fab285_o.jpg"/>
     <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </dcterms:StillImage>
+    <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528#exif"/>
+   </dcterms:StillImage>
 
-  <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/california">
+   <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/california">
     <skos:prefLabel>california</skos:prefLabel>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/tags/california"/>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:comment rdf:about="http://www.flickr.com/photos/straup/30763528/#comment8400103">
+   <flickr:comment rdf:about="http://www.flickr.com/photos/straup/30763528/#comment8400103">
     <dc:identifier>6065-30763528-8400103</dc:identifier>
     <dc:created>2005-08-02T18:52:23</dc:created>
     <a:body>moooaahahaahahmooo</a:body>
     <dc:creator rdf:resource="http://www.flickr.com/people/44124415257@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:comment>
+   </flickr:comment>
 
-  <flickr:user rdf:about="http://www.flickr.com/people/44124415257@N01">
-    <foaf:mbox_sha1sum>4f6f211958d5217ef0d10f7f5cd9a69cd66f217e</foaf:mbox_sha1sum>
-    <foaf:name>Karl Dubost</foaf:name>
+   <flickr:user rdf:about="http://www.flickr.com/people/44124415257@N01">
+    <foaf:mbox_sha1sum>b2310525591ca71b1cb9c2e3226dec1765d76c1e</foaf:mbox_sha1sum>
+    <foaf:name></foaf:name>
     <foaf:nick>karlcow</foaf:nick>
-  </flickr:user>
+   </flickr:user>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140939">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140939">
     <i:boundingBox>326 181 97 25</i:boundingBox>
     <a:body>Did you see that this shirt makes me a beautiful breast?</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/44124415257@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
+   </flickr:note>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140952">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140952">
     <i:boundingBox>9 205 145 55</i:boundingBox>
     <a:body>Do you want my opinion? There's a love affair going on here… Anyway. Talking non sense. We all know Heather is committed to Flickr. She even only dresses at FlickrApparel. Did they say &amp;quot;No Logo&amp;quot;. Doh Dude.</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/44124415257@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
 
-  <flickr:photoset rdf:about="http://www.flickr.com/photos/35034348999@N01/sets/1082058">
+   </flickr:note>
+
+   <flickr:photoset rdf:about="http://www.flickr.com/photos/35034348999@N01/sets/1082058">
     <dc:description></dc:description>
     <dc:title>Flickr</dc:title>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
-  </flickr:photoset>
+   </flickr:photoset>
 
-  <flickr:user rdf:about="http://www.flickr.com/people/34427469121@N01">
+   <flickr:user rdf:about="http://www.flickr.com/people/34427469121@N01">
     <foaf:mbox_sha1sum>00d5b413e52b4d7d35dc982102c49e930a0ef631</foaf:mbox_sha1sum>
     <foaf:name>George Oates</foaf:name>
     <foaf:nick>George</foaf:nick>
-  </flickr:user>
+   </flickr:user>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140946">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140946">
     <i:boundingBox>355 31 103 95</i:boundingBox>
     <a:body>(Yes… I love you heather, you are my dream star)</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/44124415257@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
+   </flickr:note>
 
-  <rdf:Description rdf:about="x-urn:flickr:tag">
+   <rdf:Description rdf:about="x-urn:flickr:tag">
     <rdfs:subClassOf rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
-  </rdf:Description>
+   </rdf:Description>
 
-  <flickr:tag rdf:about="http://www.flickr.com/tags/usa">
+   <flickr:tag rdf:about="http://www.flickr.com/tags/usa">
     <skos:prefLabel>usa</skos:prefLabel>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:tag rdf:about="http://www.flickr.com/tags/california">
+   <flickr:tag rdf:about="http://www.flickr.com/tags/california">
     <skos:prefLabel>california</skos:prefLabel>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/geotagged">
+   <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/geotagged">
     <skos:prefLabel>geotagged</skos:prefLabel>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/tags/geotagged"/>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/sanfrancisco">
+   <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/sanfrancisco">
     <skos:prefLabel>san francisco</skos:prefLabel>
     <skos:altLabel>sanfrancisco</skos:altLabel>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/tags/sanfrancisco"/>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:user rdf:about="http://www.flickr.com/people/32373682187@N01">
+   <flickr:user rdf:about="http://www.flickr.com/people/32373682187@N01">
     <foaf:mbox_sha1sum>479d12dec2090705278d8b2af2c50ac2c46b94d4</foaf:mbox_sha1sum>
     <foaf:name>heather powazek champ</foaf:name>
     <foaf:nick>heather</foaf:nick>
-  </flickr:user>
+   </flickr:user>
 
-  <flickr:tag rdf:about="http://www.flickr.com/tags/geotagged">
+   <flickr:tag rdf:about="http://www.flickr.com/tags/geotagged">
     <skos:prefLabel>geotagged</skos:prefLabel>
-  </flickr:tag>
+   </flickr:tag>
 
-  <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285.jpg">
+   <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285.jpg">
     <dcterms:relation>Medium</dcterms:relation>
     <exifi:height>375</exifi:height>
     <exifi:width>500</exifi:width>
     <dcterms:isVersionOf rdf:resource="http://static.flickr.com/23/30763528_a981fab285_o.jpg"/>
     <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </dcterms:StillImage>
+    <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528#exif"/>
+   </dcterms:StillImage>
 
-  <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/geolat377742">
+   <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/geolat377742">
     <skos:altLabel>geolat377742</skos:altLabel>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <skos:prefLabel rdf:resource="geo:lat=37.7742"/>
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/tags/geolat377742"/>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1142648">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1142648">
     <i:boundingBox>202 224 50 50</i:boundingBox>
     <a:body>dude! who did this?</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/32373682187@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
+   </flickr:note>
 
-  <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/cameraphone">
+   <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/cameraphone">
     <skos:prefLabel>cameraphone</skos:prefLabel>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/tags/cameraphone"/>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:user rdf:about="http://www.flickr.com/people/35034348999@N01">
+   <flickr:user rdf:about="http://www.flickr.com/people/35034348999@N01">
     <foaf:mbox_sha1sum>a4d1b5e38db5e2ed4f847f9f09fd51cf59bc0d3f</foaf:mbox_sha1sum>
     <foaf:name>Aaron Straup Cope</foaf:name>
     <foaf:nick>straup</foaf:nick>
-  </flickr:user>
+   </flickr:user>
 
-  <rdf:Description rdf:about="x-urn:flickr:comment">
+   <rdf:Description rdf:about="x-urn:flickr:comment">
     <rdfs:subClassOf rdf:resource="http://www.w3.org/2000/10/annotation-nsAnnotation"/>
-  </rdf:Description>
+   </rdf:Description>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140942">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140942">
     <i:boundingBox>468 141 22 26</i:boundingBox>
     <a:body>*sigh*</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/44124415257@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
+   </flickr:note>
 
-  <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/usa">
+   <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/usa">
     <skos:prefLabel>usa</skos:prefLabel>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/tags/usa"/>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:tag rdf:about="http://www.flickr.com/tags/cameraphone">
+   <flickr:tag rdf:about="http://www.flickr.com/tags/cameraphone">
     <skos:prefLabel>cameraphone</skos:prefLabel>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1142656">
+   <rdf:Description rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#exif">
+    <exif:flash>32</exif:flash>
+    <exif:digitalZoomRatio>100/100</exif:digitalZoomRatio>
+    <exif:isoSpeedRatings>1250</exif:isoSpeedRatings>
+    <exif:pixelXDimension>1280</exif:pixelXDimension>
+    <exif:apertureValue>336/100</exif:apertureValue>
+    <exif:pixelYDimension>960</exif:pixelYDimension>
+    <exif:focalLength>4.5 mm</exif:focalLength>
+    <exif:dateTimeDigitized>2005-08-02T18:12:19PDT</exif:dateTimeDigitized>
+    <exif:colorSpace>sRGB</exif:colorSpace>
+    <exif:fNumber>f/3.2</exif:fNumber>
+    <exif:dateTimeOriginal>2005-08-02T18:12:19PDT</exif:dateTimeOriginal>
+    <exif:shutterSpeedValue>4321/1000</exif:shutterSpeedValue>
+    <exif:exposureTime>0.05 sec (263/5260)</exif:exposureTime>
+    <exif:gainControl>High gain up</exif:gainControl>
+   </rdf:Description>
+
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1142656">
     <i:boundingBox>357 193 81 28</i:boundingBox>
     <a:body>eww!</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/32373682187@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
+   </flickr:note>
 
-  <flickr:tag rdf:about="http://www.flickr.com/tags/sanfrancisco">
+   <flickr:tag rdf:about="http://www.flickr.com/tags/sanfrancisco">
     <skos:prefLabel>sanfrancisco</skos:prefLabel>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:comment rdf:about="http://www.flickr.com/photos/straup/30763528/#comment8399772">
+   <flickr:comment rdf:about="http://www.flickr.com/photos/straup/30763528/#comment8399772">
     <dc:identifier>6065-30763528-8399772</dc:identifier>
     <dc:created>2005-08-02T18:44:52</dc:created>
     <a:body>&amp;quot;you have been note-spammed by a passing mad cow...&amp;quot;
 :)</a:body>
     <dc:creator rdf:resource="http://www.flickr.com/people/32373689382@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:comment>
+   </flickr:comment>
 
-  <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_m.jpg">
+   <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_m.jpg">
     <dcterms:relation>Small</dcterms:relation>
     <exifi:height>180</exifi:height>
     <exifi:width>240</exifi:width>
     <dcterms:isVersionOf rdf:resource="http://static.flickr.com/23/30763528_a981fab285_o.jpg"/>
     <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </dcterms:StillImage>
+    <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528#exif"/>
+   </dcterms:StillImage>
 
-  <flickr:tag rdf:about="http://www.flickr.com/tags/geolong122417068">
+   <flickr:tag rdf:about="http://www.flickr.com/tags/geolong122417068">
     <skos:prefLabel>geolong122417068</skos:prefLabel>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1143239">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1143239">
     <i:boundingBox>184 164 50 50</i:boundingBox>
     <a:body>Baaaaarp!</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/34427469121@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
+   </flickr:note>
 
-  <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_t.jpg">
+   <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_t.jpg">
     <dcterms:relation>Thumbnail</dcterms:relation>
     <exifi:height>75</exifi:height>
     <exifi:width>100</exifi:width>
     <dcterms:isVersionOf rdf:resource="http://static.flickr.com/23/30763528_a981fab285_o.jpg"/>
     <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </dcterms:StillImage>
+    <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528#exif"/>
+   </dcterms:StillImage>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140945">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1140945">
     <i:boundingBox>433 103 50 50</i:boundingBox>
     <a:body>(fuck… fuck…)</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/44124415257@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
+   </flickr:note>
 
-  <rdf:Description rdf:about="x-urn:flickr:user">
+   <rdf:Description rdf:about="x-urn:flickr:user">
     <rdfs:subClassOf rdf:resource="http://xmlns.com/foaf/0.1/Person"/>
-  </rdf:Description>
+   </rdf:Description>
 
-  <flickr:grouppool rdf:about="http://www.flickr.com/groups/97155967@N00/pool">
+   <flickr:grouppool rdf:about="http://www.flickr.com/groups/97155967@N00/pool">
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/groups/97155967@N00"/>
-  </flickr:grouppool>
+   </flickr:grouppool>
 
-  <flickr:user rdf:about="http://www.flickr.com/people/32373689382@N01">
+   <flickr:user rdf:about="http://www.flickr.com/people/32373689382@N01">
     <foaf:mbox_sha1sum>e0d207bb5643d4d7dd60e72d4ce2a94bae0e13b6</foaf:mbox_sha1sum>
     <foaf:name>Boris Anthony</foaf:name>
     <foaf:nick>bopuc</foaf:nick>
-  </flickr:user>
+   </flickr:user>
 
-  <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/geolong122417068">
+   <flickr:tag rdf:about="http://www.flickr.com/photos/35034348999@N01/tags/geolong122417068">
     <skos:altLabel>geolong122417068</skos:altLabel>
     <dc:creator rdf:resource="http://www.flickr.com/people/35034348999@N01"/>
     <skos:prefLabel rdf:resource="geo:long=-122.417068"/>
     <dcterms:isPartOf rdf:resource="http://www.flickr.com/tags/geolong122417068"/>
-  </flickr:tag>
+   </flickr:tag>
 
-  <flickr:group rdf:about="http://www.flickr.com/groups/97155967@N00">
+   <flickr:group rdf:about="http://www.flickr.com/groups/97155967@N00">
     <dc:description></dc:description>
     <dc:title>aaronland</dc:title>
-  </flickr:group>
+   </flickr:group>
 
-  <flickr:tag rdf:about="http://www.flickr.com/tags/geolat377742">
+   <flickr:tag rdf:about="http://www.flickr.com/tags/geolat377742">
     <skos:prefLabel>geolat377742</skos:prefLabel>
-  </flickr:tag>
+   </flickr:tag>
 
-  <cc:License rdf:about="http://creativecommons.org/licenses/by-nd/2.0/">
+   <cc:License rdf:about="http://creativecommons.org/licenses/by-nd/2.0/">
     <cc:requires rdf:resource="http://web.resource.org/cc/Notice"/>
     <cc:requires rdf:resource="http://web.resource.org/cc/Attribution"/>
     <cc:requires rdf:resource="http://web.resource.org/cc/ShareAlike"/>
     <cc:permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
     <cc:permits rdf:resource="http://web.resource.org/cc/Distribution"/>
-  </cc:License>
+   </cc:License>
 
-  <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_o.jpg">
+   <dcterms:StillImage rdf:about="http://static.flickr.com/23/30763528_a981fab285_o.jpg">
     <dcterms:relation>Original</dcterms:relation>
     <exifi:height>960</exifi:height>
     <exifi:width>1280</exifi:width>
     <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </dcterms:StillImage>
+    <rdfs:seeAlso rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528#exif"/>
+   </dcterms:StillImage>
 
-  <rdf:Description rdf:about="x-urn:flickr:note">
+   <rdf:Description rdf:about="x-urn:flickr:note">
     <rdfs:subClassOf rdf:resource="http://www.w3.org/2000/10/annotation-nsAnnotation"/>
-  </rdf:Description>
+   </rdf:Description>
 
-  <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1148950">
+   <flickr:note rdf:about="http://www.flickr.com/photos/35034348999@N01/30763528#note-1148950">
     <i:boundingBox>342 197 28 33</i:boundingBox>
     <a:body>Is that just one big boob, or...?</a:body>
     <i:regionDepicts rdf:resource="http://static.flickr.com/23/30763528_a981fab285.jpg"/>
     <a:author rdf:resource="http://www.flickr.com/people/34427469121@N01"/>
     <a:annotates rdf:resource="http://www.flickr.com/photos/35034348999@N01/30763528"/>
-  </flickr:note>
-
- </rdf:RDF>
+   </flickr:note>
+  </rdf:RDF>
 
 =head1 SEE ALSO
 
